# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr
from cardscan_client.models.upload_parameters import UploadParameters

class GenerateCardUploadUrl200Response(BaseModel):
    """
    GenerateCardUploadUrl200Response
    """
    card_id: StrictStr = Field(...)
    scan_id: StrictStr = Field(...)
    upload_url: StrictStr = Field(default=..., description="The URL to upload the card image.")
    upload_parameters: UploadParameters = Field(...)
    __properties = ["card_id", "scan_id", "upload_url", "upload_parameters"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GenerateCardUploadUrl200Response:
        """Create an instance of GenerateCardUploadUrl200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of upload_parameters
        if self.upload_parameters:
            _dict['upload_parameters'] = self.upload_parameters.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GenerateCardUploadUrl200Response:
        """Create an instance of GenerateCardUploadUrl200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GenerateCardUploadUrl200Response.parse_obj(obj)

        _obj = GenerateCardUploadUrl200Response.parse_obj({
            "card_id": obj.get("card_id"),
            "scan_id": obj.get("scan_id"),
            "upload_url": obj.get("upload_url"),
            "upload_parameters": UploadParameters.from_dict(obj.get("upload_parameters")) if obj.get("upload_parameters") is not None else None
        })
        return _obj


