# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool
from cardscan_client.models.create_card_request_backside import CreateCardRequestBackside

class CreateCardRequest(BaseModel):
    """
    CreateCardRequest
    """
    enable_backside_scan: Optional[StrictBool] = Field(default=False, description="Whether to enable backside scanning")
    enable_livescan: Optional[StrictBool] = Field(default=False, description="Whether to enable live scanning")
    backside: Optional[CreateCardRequestBackside] = None
    __properties = ["enable_backside_scan", "enable_livescan", "backside"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateCardRequest:
        """Create an instance of CreateCardRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of backside
        if self.backside:
            _dict['backside'] = self.backside.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateCardRequest:
        """Create an instance of CreateCardRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateCardRequest.parse_obj(obj)

        _obj = CreateCardRequest.parse_obj({
            "enable_backside_scan": obj.get("enable_backside_scan") if obj.get("enable_backside_scan") is not None else False,
            "enable_livescan": obj.get("enable_livescan") if obj.get("enable_livescan") is not None else False,
            "backside": CreateCardRequestBackside.from_dict(obj.get("backside")) if obj.get("backside") is not None else None
        })
        return _obj


