# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class ScanMetadataVideoTrack(BaseModel):
    """
    Video track details  # noqa: E501
    """
    aspect_ratio: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="aspectRatio")
    device_id: Optional[StrictStr] = Field(default=None, alias="deviceId")
    frame_rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="frameRate")
    group_id: Optional[StrictStr] = Field(default=None, alias="groupId")
    height: Optional[StrictInt] = None
    resize_mode: Optional[StrictStr] = Field(default=None, alias="resizeMode")
    width: Optional[StrictInt] = None
    __properties = ["aspectRatio", "deviceId", "frameRate", "groupId", "height", "resizeMode", "width"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ScanMetadataVideoTrack:
        """Create an instance of ScanMetadataVideoTrack from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ScanMetadataVideoTrack:
        """Create an instance of ScanMetadataVideoTrack from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ScanMetadataVideoTrack.parse_obj(obj)

        _obj = ScanMetadataVideoTrack.parse_obj({
            "aspect_ratio": obj.get("aspectRatio"),
            "device_id": obj.get("deviceId"),
            "frame_rate": obj.get("frameRate"),
            "group_id": obj.get("groupId"),
            "height": obj.get("height"),
            "resize_mode": obj.get("resizeMode"),
            "width": obj.get("width")
        })
        return _obj


