# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class EligibilityApiResponseEligibilityRequestSubscriber(BaseModel):
    """
    EligibilityApiResponseEligibilityRequestSubscriber
    """
    first_name: Optional[StrictStr] = Field(default=None, alias="firstName", description="The first name of the subscriber.")
    last_name: Optional[StrictStr] = Field(default=None, alias="lastName", description="The last name of the subscriber.")
    member_id: Optional[StrictStr] = Field(default=None, alias="memberId", description="The member ID of the subscriber.")
    dob: Optional[StrictStr] = Field(default=None, description="The date of birth of the subscriber.")
    __properties = ["firstName", "lastName", "memberId", "dob"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EligibilityApiResponseEligibilityRequestSubscriber:
        """Create an instance of EligibilityApiResponseEligibilityRequestSubscriber from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EligibilityApiResponseEligibilityRequestSubscriber:
        """Create an instance of EligibilityApiResponseEligibilityRequestSubscriber from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EligibilityApiResponseEligibilityRequestSubscriber.parse_obj(obj)

        _obj = EligibilityApiResponseEligibilityRequestSubscriber.parse_obj({
            "first_name": obj.get("firstName"),
            "last_name": obj.get("lastName"),
            "member_id": obj.get("memberId"),
            "dob": obj.get("dob")
        })
        return _obj


