# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from cardscan_client.models.eligibility_api_response_eligibility_request_subscriber import EligibilityApiResponseEligibilityRequestSubscriber
from cardscan_client.models.provider_dto import ProviderDto

class EligibilityApiResponseEligibilityRequest(BaseModel):
    """
    The eligibility request.  # noqa: E501
    """
    control_number: Optional[StrictStr] = Field(default=None, alias="controlNumber", description="The control number of the claim.")
    trading_partner_service_id: Optional[StrictStr] = Field(default=None, alias="tradingPartnerServiceId", description="The ID of the trading partner service.")
    provider: Optional[ProviderDto] = None
    subscriber: Optional[EligibilityApiResponseEligibilityRequestSubscriber] = None
    __properties = ["controlNumber", "tradingPartnerServiceId", "provider", "subscriber"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EligibilityApiResponseEligibilityRequest:
        """Create an instance of EligibilityApiResponseEligibilityRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of provider
        if self.provider:
            _dict['provider'] = self.provider.to_dict()
        # override the default output from pydantic by calling `to_dict()` of subscriber
        if self.subscriber:
            _dict['subscriber'] = self.subscriber.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EligibilityApiResponseEligibilityRequest:
        """Create an instance of EligibilityApiResponseEligibilityRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EligibilityApiResponseEligibilityRequest.parse_obj(obj)

        _obj = EligibilityApiResponseEligibilityRequest.parse_obj({
            "control_number": obj.get("controlNumber"),
            "trading_partner_service_id": obj.get("tradingPartnerServiceId"),
            "provider": ProviderDto.from_dict(obj.get("provider")) if obj.get("provider") is not None else None,
            "subscriber": EligibilityApiResponseEligibilityRequestSubscriber.from_dict(obj.get("subscriber")) if obj.get("subscriber") is not None else None
        })
        return _obj


